<?php
/*-
 * Copyright (c) 2008 Fredrik Lindberg - http://www.shapeshifter.se
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

/*
 * Database interface
 */

abstract class SQLConnector
{
    private $m_dbAddress;
    private $m_dbAccount;
    private $m_dbPwd;
    private $m_dbName;

    public function __construct($address, $account, $pwd, $name) {
        $this->m_dbAddress = $address;
        $this->m_dbAccount = $account;
        $this->m_dbPwd = $pwd;
        $this->m_dbName = $name;
        $this->connect($this->m_dbAddress, $this->m_dbAccount,
            $this->m_dbPwd, $this->m_dbName);
    }

    public function __destruct() {
        $this->disconnect();
    }

    public function __sleep() {
        $this->disconnect();
        return array('m_dbAddress', 'm_dbAccount', 'm_dbPwd', 'm_dbName');
    }

    public function __wakeup() {
        $this->connect($this->m_dbAddress, $this->m_dbAccount,
            $this->m_dbPwd, $this->m_dbName);
    }

    abstract protected function connect($address, $account, $pwd, $name);
    abstract protected function disconnect();
    abstract function query($query);
    abstract function fetchRow();
    abstract function fetchAll();
    abstract function getNumRows();
    abstract function freeResult();
    abstract function getError();
}

?>